import { Button } from "@/components/ui/button"
import { Card, CardContent } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { ArrowRight, Book, Mail, Smartphone, Zap } from 'lucide-react'
import Link from "next/link"
import Image from "next/image"

export default function Component() {
  return (
    <div className="min-h-screen bg-[#020B2D] text-white overflow-hidden relative">
      {/* Background */}
      <div className="absolute inset-0 z-0">
        <div className="absolute inset-0 bg-[url('/grid.svg')] opacity-10" />
        <div className="absolute inset-0 bg-gradient-to-r from-blue-500/10 to-purple-500/10" />
      </div>

      {/* Navigation */}
      <nav className="relative z-10 border-b border-white/10">
        <div className="container mx-auto px-4 py-4">
          <div className="flex items-center justify-between">
            <Link href="/" className="flex items-center space-x-2">
              <Image
                src="/placeholder.svg?height=32&width=32"
                alt="CHIPS Logo"
                width={32}
                height={32}
                className="w-8 h-8"
              />
              <span className="text-2xl font-bold text-[#C5FF32]">CHIPS</span>
            </Link>
            <Button className="bg-[#C5FF32] text-black hover:bg-[#B4EE21]">
              Get the Book
            </Button>
          </div>
        </div>
      </nav>

      {/* Hero Section */}
      <section className="relative z-10 py-12 lg:py-20">
        <div className="container mx-auto px-4">
          <div className="text-center max-w-4xl mx-auto">
            <h1 className="text-4xl md:text-6xl font-bold mb-6">
              CHIPS: Changing Habits Improves Personal Success
            </h1>
            <p className="text-xl text-white/80 mb-8">
              A Self-Help Game that Rewards Positive Habits!
            </p>
            <div className="mb-12 aspect-video">
              <iframe
                width="100%"
                height="100%"
                src="https://www.youtube.com/embed/44wT8f9fcp0"
                title="CHIPS: Changing Habits Improves Personal Success"
                frameBorder="0"
                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                allowFullScreen
              ></iframe>
            </div>
            <div className="flex flex-col sm:flex-row justify-center items-center gap-4 mb-8">
              <Button className="bg-[#C5FF32] text-black hover:bg-[#B4EE21] text-lg px-8 py-4 w-full sm:w-auto">
                <Book className="mr-2 h-5 w-5" />
                Get the Book
              </Button>
              <Button variant="outline" className="border-white/20 text-white hover:bg-white/10 text-lg px-8 py-4 w-full sm:w-auto">
                <ArrowRight className="mr-2 h-5 w-5" />
                Learn More
              </Button>
            </div>
          </div>
        </div>
      </section>

      {/* Email Collection Section */}
      <section className="relative z-10 py-16 bg-black/20">
        <div className="container mx-auto px-4">
          <div className="max-w-2xl mx-auto text-center">
            <h2 className="text-3xl font-bold mb-6">Stay Updated on CHIPS</h2>
            <p className="text-lg mb-8">
              Get exclusive updates, tips, and early access to new features. Join our community today!
            </p>
            <form className="flex flex-col sm:flex-row gap-4">
              <Input
                type="email"
                placeholder="Enter your email"
                className="bg-white/10 border-white/20 text-white placeholder-white/50"
              />
              <Button type="submit" className="bg-[#C5FF32] text-black hover:bg-[#B4EE21]">
                <Mail className="mr-2 h-5 w-5" />
                Subscribe
              </Button>
            </form>
          </div>
        </div>
      </section>

      {/* Book Promotion Section */}
      <section className="relative z-10 py-16">
        <div className="container mx-auto px-4">
          <div className="grid md:grid-cols-2 gap-12 items-center">
            <div>
              <h2 className="text-3xl font-bold mb-6">Get the CHIPS Book</h2>
              <p className="text-lg mb-4">
                "Changing Habits Improves Personal Success" - The companion book to our revolutionary app.
              </p>
              <p className="text-lg mb-8">
                Learn the strategies and principles behind CHIPS, and supercharge your personal development journey.
              </p>
              <Button className="bg-[#C5FF32] text-black hover:bg-[#B4EE21] text-lg px-8 py-4">
                <Book className="mr-2 h-5 w-5" />
                Buy Now
              </Button>
            </div>
            <div className="flex justify-center">
              <Image
                src="/placeholder.svg?height=400&width=300"
                alt="CHIPS Book Cover"
                width={300}
                height={400}
                className="rounded-lg shadow-lg"
              />
            </div>
          </div>
        </div>
      </section>

      {/* Key Features */}
      <section className="relative z-10 py-16 bg-black/20">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-12">Key Features of CHIPS</h2>
          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
            <Card className="bg-white/5 border-white/10">
              <CardContent className="p-6">
                <Smartphone className="h-12 w-12 text-[#C5FF32] mb-4" />
                <h3 className="text-xl font-bold mb-2">Mobile Game</h3>
                <p className="text-white/70">
                  A gamified approach to personal development, available on your smartphone.
                </p>
              </CardContent>
            </Card>
            <Card className="bg-white/5 border-white/10">
              <CardContent className="p-6">
                <Book className="h-12 w-12 text-[#C5FF32] mb-4" />
                <h3 className="text-xl font-bold mb-2">Companion Book</h3>
                <p className="text-white/70">
                  In-depth strategies and principles to complement your in-app experience.
                </p>
              </CardContent>
            </Card>
            <Card className="bg-white/5 border-white/10">
              <CardContent className="p-6">
                <Zap className="h-12 w-12 text-[#C5FF32] mb-4" />
                <h3 className="text-xl font-bold mb-2">Habit Formation</h3>
                <p className="text-white/70">
                  Leverage the 21/90 rule to build lasting positive habits.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="relative z-10 py-20 bg-[#C5FF32]/10">
        <div className="container mx-auto px-4">
          <div className="text-center max-w-3xl mx-auto">
            <h2 className="text-3xl md:text-4xl font-bold mb-6">
              Ready to Change Your Habits and Improve Your Success?
            </h2>
            <p className="text-white/80 mb-8">
              Get started with CHIPS today and transform your life!
            </p>
            <div className="flex flex-col sm:flex-row justify-center items-center gap-4">
              <Button className="bg-[#C5FF32] text-black hover:bg-[#B4EE21] text-lg px-8 py-4 w-full sm:w-auto">
                <Book className="mr-2 h-5 w-5" />
                Get the Book
              </Button>
              <Button variant="outline" className="border-white/20 text-white hover:bg-white/10 text-lg px-8 py-4 w-full sm:w-auto">
                <Mail className="mr-2 h-5 w-5" />
                Join Mailing List
              </Button>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="relative z-10 py-8 border-t border-white/10">
        <div className="container mx-auto px-4">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <div className="text-white/60 mb-4 md:mb-0">
              © 2024 CHIPS. All rights reserved.
            </div>
            <div className="flex space-x-4">
              <Link href="#" className="text-white/60 hover:text-white">Privacy Policy</Link>
              <Link href="#" className="text-white/60 hover:text-white">Terms of Service</Link>
              <Link href="https://thatsnotwagyu.com/product/changing-habits-improves-personal-success" className="text-white/60 hover:text-white">
                Learn More
              </Link>
            </div>
          </div>
        </div>
      </footer>
    </div>
  )
}