document.addEventListener('DOMContentLoaded', function() {
    // Handle email subscription form
    const subscribeForm = document.getElementById('subscribe-form');
    if (subscribeForm) {
        subscribeForm.addEventListener('submit', async function(e) {
            e.preventDefault();
            
            const emailInput = subscribeForm.querySelector('input[type="email"]');
            const submitButton = subscribeForm.querySelector('button[type="submit"]');
            const originalButtonText = submitButton.innerHTML;
            
            try {
                submitButton.disabled = true;
                submitButton.innerHTML = 'Subscribing...';
                
                const formData = new FormData();
                formData.append('email', emailInput.value);
                
                const response = await fetch('/subscribe', {
                    method: 'POST',
                    body: formData
                });
                
                const data = await response.json();
                
                if (response.ok) {
                    alert(data.message);
                    emailInput.value = '';
                } else {
                    alert(data.error || 'Something went wrong. Please try again.');
                }
            } catch (error) {
                alert('An error occurred. Please try again later.');
            } finally {
                submitButton.disabled = false;
                submitButton.innerHTML = originalButtonText;
            }
        });
    }

    // Enhanced smooth scroll handling
    document.querySelectorAll('[data-scroll="smooth"]').forEach(button => {
        button.addEventListener('click', (e) => {
            e.preventDefault();
            const targetId = button.getAttribute('href').substring(1);
            const targetElement = document.getElementById(targetId);
            
            if (targetElement) {
                // Get navbar height for offset
                const navbar = document.querySelector('.navbar');
                const navbarHeight = navbar ? navbar.offsetHeight : 0;
                
                // Calculate position with better offset handling
                const targetRect = targetElement.getBoundingClientRect();
                const targetPosition = window.pageYOffset + targetRect.top;
                const offsetPosition = targetPosition - navbarHeight - 20; // Additional 20px padding
                
                // Smooth scroll with better animation handling
                window.scrollTo({
                    top: offsetPosition,
                    behavior: 'smooth'
                });

                // Focus handling with proper timing
                const scrollDuration = Math.abs(window.pageYOffset - offsetPosition) / 2; // Dynamic duration
                const minDuration = 500; // Minimum duration
                const maxDuration = 1000; // Maximum duration
                const finalDuration = Math.min(Math.max(scrollDuration, minDuration), maxDuration);

                setTimeout(() => {
                    targetElement.focus({ preventScroll: true });
                }, finalDuration);
            }
        });
    });
});
